@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
-VERSION = '1.2-beta'
+VERSION = '1.2.2-beta'
 
 from .conf import Configuration
+from .template import ProjectCreator
 
 
